CreateSubscriptionParameters class

Properties

bundleIdentifier ↔ String?
getter/setter pair
channel ↔ String?
getter/setter pair
environment ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
platform ↔ String?
getter/setter pair
pushToken ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
udid ↔ String?
getter/setter pair

Methods

getRequestParameters() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited