CubeCustomObject class

Inheritance

Constructors

CubeCustomObject(String className)
CubeCustomObject.fromJson(Map<String, dynamic> json)

Properties

className ↔ String?
getter/setter pairinherited
createdAt ↔ int?
getter/setter pair
fields ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
parentId ↔ dynamic
getter/setter pair
permissions ↔ CubeCustomObjectPermissions?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt ↔ int?
getter/setter pair
userId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited