DeleteSubscriptionQuery class

Inheritance

Constructors

DeleteSubscriptionQuery(int subscriptionId)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId ↔ int
getter/setter pair

Methods

buildQueryUrl(List specificParts) → String
inherited
getTokenExpirationDateFromResponse(RestResponse response) → DateTime?
inherited
handelError(Object error) → dynamic
inherited
handleResponse(RestResponse response) → dynamic
inherited
isSessionRequired() → bool
inherited
isUserRequired() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
perform() → Future<void>
inherited
prepareSessionIfNeed() → Future<CubeSession?>
inherited
processResult(String responseBody) → void
override
putValue(Map<String?, dynamic> parametersMap, String key, dynamic value) → void
inherited
setBody(RestRequest request) → void
inherited
setHeaders(RestRequest request) → void
inherited
setMethod(RestRequest request) → void
override
setParams(RestRequest request) → void
inherited
setupRequest(RestRequest request) → void
inherited
setUrl(RestRequest request) → void
override
toString() → String
A string representation of this object.
inherited
updateTokenExpirationDate(RestResponse response) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited